# How to create a signer.

For what Signers are, check [Farcaster Signers](https://paragraph.xyz/@purplesubmarine/farcaster-signers)
on Purple Submarine.

In order to create a new Signer for your account using `fario-new-signer`, you need to have your private
key.